==> estateplat-common-1.2.4-20181031.015027-44-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfYxsxk.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-11
 * @description 新建商品房预售许可
 */
@Table(name = "fcjy_xjspf_yxsxk")
public class FcjyXjspfYxsxk {
    @Id
    private String xkid;//主键
    private Long xkbh;//许可编号
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String xmid;//项目ID
    private Long xmbh;//项目编号
    private String xmmc;//项目名称
    private String fwzls;//房屋坐落市
    private String qxh;//区县号
    private String ysfw;//预售范围
    private Date fzrq;//发证日期
    private Date yxrq;//有效日期
    private Double yjjgmj;//预计竣工面积（平方米）
    private Integer yjjgts;//预计竣工套数
    private Date yjjgrq;//预计竣工日期
    private Double zjzmj;//总建筑面积（平方米）
    private Double xkmj;//许可面积（平方米）
    private Integer xkts;//许可套数
    private Date xsksrq;//销售开始日期
    private Date xsjsrq;//销售结束日期
    private Double pzyszfzmj;//批准预售住房总面积（平方米）
    private Double zfyssbpjjg;//住房预售申报平均价格（元/平方米）
    private Double pzyssyyyyfzmj;//批准预售商业营业用房总面积（平方米）
    private Double syyyyfyssbpjjg;//商业营业用房预售申报平均价格（元/平方米）
    private Double pzysbglzmj;//批准预售办公楼总面积（平方米）
    private Double bglyssbpjjg;//办公楼预售申报平均价格（元/平方米）
    private Double pzysqtfwzmj;//批准预售其他房屋总面积（平方米）
    private Double qtfwsbpjjg;//其他房屋申报平均价格（元/平方米）
    private String xkzh;//许可证号
    private String djjg;//登记机构
    private String sfzx;//0：未注销1：注销
    private String zxyy;//注销原因
    private String bz;//备注
    private String zt;//状态（状态字典表）
    private String sfdj;//是否冻结(0或空不是，1是)
    private String lx;//类型（YS：预售 XS：现售 ）
    private Date ysyxqz;//预售有效期至
    private String xsdl;//销售代理
    private Date kgrq;//开工日期
    private Date jfrq;//交付日期
    private String wqzxbz;//外墙装修标准
    private String nqzxbz;//内墙装修标准
    private String dpzxbz;//顶棚装修标准
    private String dmzxbz;//地面装修标准
    private String qtzxbz;//其他装修标准
    private String zkzyzh;//专款专用账号
    private String khh;//开户行
    private String hm;//户名
    private String gtbw;//分摊部位
    private Double gtmj;//公摊面积
    private String wyglgs;//物业管理公司
    private String wyfwfxm;//物业服务费项目
    private Double zzsfbz;//住宅收费标准（元/平方米）
    private Double sysfbz;//商业收费标准（元/平方米）
    private Double bgsfbz;//办公收费标准（元/平方米）
    private Double cksfbz;//车库收费标准（元/平方米）
    private Double qtsfbz;//其他收费标准（元/平方米）
    private Integer zts;//总套数
    private Double zje;//总金额
    private Double blfjzmj;//保留房建筑面积（平方米）
    private Integer blfzts;//保留房总套数
    private Double syyfjzgm;//商业用房建筑规模（平方米）
    private String syyfsgjd;//商业用房施工进度
    private Double syyfwctze;//商业用房完成投资额（万元）
    private Double syyfysjg;//商业用房预售价格（元/平方米）
    private Double zzyfjzgm;//住宅用房建筑规模（平方米）
    private String zzyfsgjd;//住宅用房施工进度
    private Double zzyfwctze;//住宅用房完成投资额（万元）
    private Double zzyfysjg;//住宅用房预售价格（元/平方米）
    private Double fzyfjzgm;//辅助用房建筑规模（平方米）
    private String fzyfsgjd;//辅助用房施工进度
    private Double fzyfwctze;//辅助用房完成投资额（万元）
    private Double fzyfysjg;//辅助用房预售价格（元/平方米）
    private Double pjjg;//平均价格
    private Date kprq;//开盘日期
    private String sfkp;//是否开盘
    private String sfyxt;//是否原系统

    public FcjyXjspfYxsxk() {
    }

    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public Long getXkbh() {
        return xkbh;
    }

    public void setXkbh(Long xkbh) {
        this.xkbh = xkbh;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Long getXmbh() {
        return xmbh;
    }

    public void setXmbh(Long xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getFwzls() {
        return fwzls;
    }

    public void setFwzls(String fwzls) {
        this.fwzls = fwzls;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getYsfw() {
        return ysfw;
    }

    public void setYsfw(String ysfw) {
        this.ysfw = ysfw;
    }

    public Date getFzrq() {
        return fzrq;
    }

    public void setFzrq(Date fzrq) {
        this.fzrq = fzrq;
    }

    public Date getYxrq() {
        return yxrq;
    }

    public void setYxrq(Date yxrq) {
        this.yxrq = yxrq;
    }

    public Double getYjjgmj() {
        return yjjgmj;
    }

    public void setYjjgmj(Double yjjgmj) {
        this.yjjgmj = yjjgmj;
    }

    public Integer getYjjgts() {
        return yjjgts;
    }

    public void setYjjgts(Integer yjjgts) {
        this.yjjgts = yjjgts;
    }

    public Date getYjjgrq() {
        return yjjgrq;
    }

    public void setYjjgrq(Date yjjgrq) {
        this.yjjgrq = yjjgrq;
    }

    public Double getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(Double zjzmj) {
        this.zjzmj = zjzmj;
    }

    public Double getXkmj() {
        return xkmj;
    }

    public void setXkmj(Double xkmj) {
        this.xkmj = xkmj;
    }

    public Integer getXkts() {
        return xkts;
    }

    public void setXkts(Integer xkts) {
        this.xkts = xkts;
    }

    public Date getXsksrq() {
        return xsksrq;
    }

    public void setXsksrq(Date xsksrq) {
        this.xsksrq = xsksrq;
    }

    public Date getXsjsrq() {
        return xsjsrq;
    }

    public void setXsjsrq(Date xsjsrq) {
        this.xsjsrq = xsjsrq;
    }

    public Double getPzyszfzmj() {
        return pzyszfzmj;
    }

    public void setPzyszfzmj(Double pzyszfzmj) {
        this.pzyszfzmj = pzyszfzmj;
    }

    public Double getZfyssbpjjg() {
        return zfyssbpjjg;
    }

    public void setZfyssbpjjg(Double zfyssbpjjg) {
        this.zfyssbpjjg = zfyssbpjjg;
    }

    public Double getPzyssyyyyfzmj() {
        return pzyssyyyyfzmj;
    }

    public void setPzyssyyyyfzmj(Double pzyssyyyyfzmj) {
        this.pzyssyyyyfzmj = pzyssyyyyfzmj;
    }

    public Double getSyyyyfyssbpjjg() {
        return syyyyfyssbpjjg;
    }

    public void setSyyyyfyssbpjjg(Double syyyyfyssbpjjg) {
        this.syyyyfyssbpjjg = syyyyfyssbpjjg;
    }

    public Double getPzysbglzmj() {
        return pzysbglzmj;
    }

    public void setPzysbglzmj(Double pzysbglzmj) {
        this.pzysbglzmj = pzysbglzmj;
    }

    public Double getBglyssbpjjg() {
        return bglyssbpjjg;
    }

    public void setBglyssbpjjg(Double bglyssbpjjg) {
        this.bglyssbpjjg = bglyssbpjjg;
    }

    public Double getPzysqtfwzmj() {
        return pzysqtfwzmj;
    }

    public void setPzysqtfwzmj(Double pzysqtfwzmj) {
        this.pzysqtfwzmj = pzysqtfwzmj;
    }

    public Double getQtfwsbpjjg() {
        return qtfwsbpjjg;
    }

    public void setQtfwsbpjjg(Double qtfwsbpjjg) {
        this.qtfwsbpjjg = qtfwsbpjjg;
    }

    public String getXkzh() {
        return xkzh;
    }

    public void setXkzh(String xkzh) {
        this.xkzh = xkzh;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getSfzx() {
        return sfzx;
    }

    public void setSfzx(String sfzx) {
        this.sfzx = sfzx;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getLx() {
        return lx;
    }

    public void setLx(String lx) {
        this.lx = lx;
    }

    public Date getYsyxqz() {
        return ysyxqz;
    }

    public void setYsyxqz(Date ysyxqz) {
        this.ysyxqz = ysyxqz;
    }

    public String getXsdl() {
        return xsdl;
    }

    public void setXsdl(String xsdl) {
        this.xsdl = xsdl;
    }

    public Date getKgrq() {
        return kgrq;
    }

    public void setKgrq(Date kgrq) {
        this.kgrq = kgrq;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getWqzxbz() {
        return wqzxbz;
    }

    public void setWqzxbz(String wqzxbz) {
        this.wqzxbz = wqzxbz;
    }

    public String getNqzxbz() {
        return nqzxbz;
    }

    public void setNqzxbz(String nqzxbz) {
        this.nqzxbz = nqzxbz;
    }

    public String getDpzxbz() {
        return dpzxbz;
    }

    public void setDpzxbz(String dpzxbz) {
        this.dpzxbz = dpzxbz;
    }

    public String getDmzxbz() {
        return dmzxbz;
    }

    public void setDmzxbz(String dmzxbz) {
        this.dmzxbz = dmzxbz;
    }

    public String getQtzxbz() {
        return qtzxbz;
    }

    public void setQtzxbz(String qtzxbz) {
        this.qtzxbz = qtzxbz;
    }

    public String getZkzyzh() {
        return zkzyzh;
    }

    public void setZkzyzh(String zkzyzh) {
        this.zkzyzh = zkzyzh;
    }

    public String getKhh() {
        return khh;
    }

    public void setKhh(String khh) {
        this.khh = khh;
    }

    public String getHm() {
        return hm;
    }

    public void setHm(String hm) {
        this.hm = hm;
    }

    public String getGtbw() {
        return gtbw;
    }

    public void setGtbw(String gtbw) {
        this.gtbw = gtbw;
    }

    public Double getGtmj() {
        return gtmj;
    }

    public void setGtmj(Double gtmj) {
        this.gtmj = gtmj;
    }

    public String getWyglgs() {
        return wyglgs;
    }

    public void setWyglgs(String wyglgs) {
        this.wyglgs = wyglgs;
    }

    public String getWyfwfxm() {
        return wyfwfxm;
    }

    public void setWyfwfxm(String wyfwfxm) {
        this.wyfwfxm = wyfwfxm;
    }

    public Double getZzsfbz() {
        return zzsfbz;
    }

    public void setZzsfbz(Double zzsfbz) {
        this.zzsfbz = zzsfbz;
    }

    public Double getSysfbz() {
        return sysfbz;
    }

    public void setSysfbz(Double sysfbz) {
        this.sysfbz = sysfbz;
    }

    public Double getBgsfbz() {
        return bgsfbz;
    }

    public void setBgsfbz(Double bgsfbz) {
        this.bgsfbz = bgsfbz;
    }

    public Double getCksfbz() {
        return cksfbz;
    }

    public void setCksfbz(Double cksfbz) {
        this.cksfbz = cksfbz;
    }

    public Double getQtsfbz() {
        return qtsfbz;
    }

    public void setQtsfbz(Double qtsfbz) {
        this.qtsfbz = qtsfbz;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public Double getZje() {
        return zje;
    }

    public void setZje(Double zje) {
        this.zje = zje;
    }

    public Double getBlfjzmj() {
        return blfjzmj;
    }

    public void setBlfjzmj(Double blfjzmj) {
        this.blfjzmj = blfjzmj;
    }

    public Integer getBlfzts() {
        return blfzts;
    }

    public void setBlfzts(Integer blfzts) {
        this.blfzts = blfzts;
    }

    public Double getSyyfjzgm() {
        return syyfjzgm;
    }

    public void setSyyfjzgm(Double syyfjzgm) {
        this.syyfjzgm = syyfjzgm;
    }

    public String getSyyfsgjd() {
        return syyfsgjd;
    }

    public void setSyyfsgjd(String syyfsgjd) {
        this.syyfsgjd = syyfsgjd;
    }

    public Double getSyyfwctze() {
        return syyfwctze;
    }

    public void setSyyfwctze(Double syyfwctze) {
        this.syyfwctze = syyfwctze;
    }

    public Double getSyyfysjg() {
        return syyfysjg;
    }

    public void setSyyfysjg(Double syyfysjg) {
        this.syyfysjg = syyfysjg;
    }

    public Double getZzyfjzgm() {
        return zzyfjzgm;
    }

    public void setZzyfjzgm(Double zzyfjzgm) {
        this.zzyfjzgm = zzyfjzgm;
    }

    public String getZzyfsgjd() {
        return zzyfsgjd;
    }

    public void setZzyfsgjd(String zzyfsgjd) {
        this.zzyfsgjd = zzyfsgjd;
    }

    public Double getZzyfwctze() {
        return zzyfwctze;
    }

    public void setZzyfwctze(Double zzyfwctze) {
        this.zzyfwctze = zzyfwctze;
    }

    public Double getZzyfysjg() {
        return zzyfysjg;
    }

    public void setZzyfysjg(Double zzyfysjg) {
        this.zzyfysjg = zzyfysjg;
    }

    public Double getFzyfjzgm() {
        return fzyfjzgm;
    }

    public void setFzyfjzgm(Double fzyfjzgm) {
        this.fzyfjzgm = fzyfjzgm;
    }

    public String getFzyfsgjd() {
        return fzyfsgjd;
    }

    public void setFzyfsgjd(String fzyfsgjd) {
        this.fzyfsgjd = fzyfsgjd;
    }

    public Double getFzyfwctze() {
        return fzyfwctze;
    }

    public void setFzyfwctze(Double fzyfwctze) {
        this.fzyfwctze = fzyfwctze;
    }

    public Double getFzyfysjg() {
        return fzyfysjg;
    }

    public void setFzyfysjg(Double fzyfysjg) {
        this.fzyfysjg = fzyfysjg;
    }

    public Double getPjjg() {
        return pjjg;
    }

    public void setPjjg(Double pjjg) {
        this.pjjg = pjjg;
    }

    public Date getKprq() {
        return kprq;
    }

    public void setKprq(Date kprq) {
        this.kprq = kprq;
    }

    public String getSfkp() {
        return sfkp;
    }

    public void setSfkp(String sfkp) {
        this.sfkp = sfkp;
    }

    public String getSfyxt() {
        return sfyxt;
    }

    public void setSfyxt(String sfyxt) {
        this.sfyxt = sfyxt;
    }
}

==> estateplat-common-1.2.4-20200703.062406-380-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfYxsxk.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-11
 * @description 新建商品房预售许可
 */
@Table(name = "fcjy_xjspf_yxsxk")
public class FcjyXjspfYxsxk {
    @Id
    private String xkid;//主键
    private Long xkbh;//许可编号
    private String fdckfqymc;//房地产开发企业名称
    private Long fdckfqybh;//房地产开发企业编号
    private String xmid;//项目ID
    private Long xmbh;//项目编号
    private String xmmc;//项目名称
    private String fwzls;//房屋坐落市
    private String qxh;//区县号
    private String ysfw;//预售范围
    private Date fzrq;//发证日期
    private Date yxrq;//有效日期
    private Double yjjgmj;//预计竣工面积（平方米）
    private Integer yjjgts;//预计竣工套数
    private Date yjjgrq;//预计竣工日期
    private Double zjzmj;//总建筑面积（平方米）
    private Double xkmj;//许可面积（平方米）
    private Integer xkts;//许可套数
    private Date xsksrq;//销售开始日期
    private Date xsjsrq;//销售结束日期
    private Double pzyszfzmj;//批准预售住房总面积（平方米）
    private Double zfyssbpjjg;//住房预售申报平均价格（元/平方米）
    private Double pzyssyyyyfzmj;//批准预售商业营业用房总面积（平方米）
    private Double syyyyfyssbpjjg;//商业营业用房预售申报平均价格（元/平方米）
    private Double pzysbglzmj;//批准预售办公楼总面积（平方米）
    private Double bglyssbpjjg;//办公楼预售申报平均价格（元/平方米）
    private Double pzysqtfwzmj;//批准预售其他房屋总面积（平方米）
    private Double qtfwsbpjjg;//其他房屋申报平均价格（元/平方米）
    private String xkzh;//许可证号
    private String djjg;//登记机构
    private String sfzx;//0：未注销1：注销
    private String zxyy;//注销原因
    private String bz;//备注
    private String zt;//状态（状态字典表）
    private String sfdj;//是否冻结(0或空不是，1是)
    private String lx;//类型（YS：预售 XS：现售 ）
    private Date ysyxqz;//预售有效期至
    private String xsdl;//销售代理
    private Date kgrq;//开工日期
    private Date jfrq;//交付日期
    private String wqzxbz;//外墙装修标准
    private String nqzxbz;//内墙装修标准
    private String dpzxbz;//顶棚装修标准
    private String dmzxbz;//地面装修标准
    private String qtzxbz;//其他装修标准
    private String zkzyzh;//专款专用账号
    private String khh;//开户行
    private String hm;//户名
    private String gtbw;//分摊部位
    private Double gtmj;//公摊面积
    private String wyglgs;//物业管理公司
    private String wyfwfxm;//物业服务费项目
    private String zzsfbz;//住宅收费标准（元/平方米）
    private String sysfbz;//商业收费标准（元/平方米）
    private String bgsfbz;//办公收费标准（元/平方米）
    private String cksfbz;//车库收费标准（元/平方米）
    private String qtsfbz;//其他收费标准（元/平方米）
    private Integer zts;//总套数
    private Double zje;//总金额
    private Double blfjzmj;//保留房建筑面积（平方米）
    private Integer blfzts;//保留房总套数
    private String syyfjzgm;//商业用房建筑规模（平方米）
    private String syyfsgjd;//商业用房施工进度
    private Double syyfwctze;//商业用房完成投资额（万元）
    private String syyfysjg;//商业用房预售价格（元/平方米）
    private String zzyfjzgm;//住宅用房建筑规模（平方米）
    private String zzyfsgjd;//住宅用房施工进度
    private Double zzyfwctze;//住宅用房完成投资额（万元）
    private String zzyfysjg;//住宅用房预售价格（元/平方米）
    private String fzyfjzgm;//辅助用房建筑规模（平方米）
    private String fzyfsgjd;//辅助用房施工进度
    private Double fzyfwctze;//辅助用房完成投资额（万元）
    private String fzyfysjg;//辅助用房预售价格（元/平方米）
    private String pjjg;//平均价格
    private Date kprq;//开盘日期
    private String sfkp;//是否开盘
    private String sfyxt;//是否原系统

    public FcjyXjspfYxsxk() {
    }

    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public Long getXkbh() {
        return xkbh;
    }

    public void setXkbh(Long xkbh) {
        this.xkbh = xkbh;
    }

    public String getFdckfqymc() {
        return fdckfqymc;
    }

    public void setFdckfqymc(String fdckfqymc) {
        this.fdckfqymc = fdckfqymc;
    }

    public Long getFdckfqybh() {
        return fdckfqybh;
    }

    public void setFdckfqybh(Long fdckfqybh) {
        this.fdckfqybh = fdckfqybh;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Long getXmbh() {
        return xmbh;
    }

    public void setXmbh(Long xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getFwzls() {
        return fwzls;
    }

    public void setFwzls(String fwzls) {
        this.fwzls = fwzls;
    }

    public String getQxh() {
        return qxh;
    }

    public void setQxh(String qxh) {
        this.qxh = qxh;
    }

    public String getYsfw() {
        return ysfw;
    }

    public void setYsfw(String ysfw) {
        this.ysfw = ysfw;
    }

    public Date getFzrq() {
        return fzrq;
    }

    public void setFzrq(Date fzrq) {
        this.fzrq = fzrq;
    }

    public Date getYxrq() {
        return yxrq;
    }

    public void setYxrq(Date yxrq) {
        this.yxrq = yxrq;
    }

    public Double getYjjgmj() {
        return yjjgmj;
    }

    public void setYjjgmj(Double yjjgmj) {
        this.yjjgmj = yjjgmj;
    }

    public Integer getYjjgts() {
        return yjjgts;
    }

    public void setYjjgts(Integer yjjgts) {
        this.yjjgts = yjjgts;
    }

    public Date getYjjgrq() {
        return yjjgrq;
    }

    public void setYjjgrq(Date yjjgrq) {
        this.yjjgrq = yjjgrq;
    }

    public Double getZjzmj() {
        return zjzmj;
    }

    public void setZjzmj(Double zjzmj) {
        this.zjzmj = zjzmj;
    }

    public Double getXkmj() {
        return xkmj;
    }

    public void setXkmj(Double xkmj) {
        this.xkmj = xkmj;
    }

    public Integer getXkts() {
        return xkts;
    }

    public void setXkts(Integer xkts) {
        this.xkts = xkts;
    }

    public Date getXsksrq() {
        return xsksrq;
    }

    public void setXsksrq(Date xsksrq) {
        this.xsksrq = xsksrq;
    }

    public Date getXsjsrq() {
        return xsjsrq;
    }

    public void setXsjsrq(Date xsjsrq) {
        this.xsjsrq = xsjsrq;
    }

    public Double getPzyszfzmj() {
        return pzyszfzmj;
    }

    public void setPzyszfzmj(Double pzyszfzmj) {
        this.pzyszfzmj = pzyszfzmj;
    }

    public Double getZfyssbpjjg() {
        return zfyssbpjjg;
    }

    public void setZfyssbpjjg(Double zfyssbpjjg) {
        this.zfyssbpjjg = zfyssbpjjg;
    }

    public Double getPzyssyyyyfzmj() {
        return pzyssyyyyfzmj;
    }

    public void setPzyssyyyyfzmj(Double pzyssyyyyfzmj) {
        this.pzyssyyyyfzmj = pzyssyyyyfzmj;
    }

    public Double getSyyyyfyssbpjjg() {
        return syyyyfyssbpjjg;
    }

    public void setSyyyyfyssbpjjg(Double syyyyfyssbpjjg) {
        this.syyyyfyssbpjjg = syyyyfyssbpjjg;
    }

    public Double getPzysbglzmj() {
        return pzysbglzmj;
    }

    public void setPzysbglzmj(Double pzysbglzmj) {
        this.pzysbglzmj = pzysbglzmj;
    }

    public Double getBglyssbpjjg() {
        return bglyssbpjjg;
    }

    public void setBglyssbpjjg(Double bglyssbpjjg) {
        this.bglyssbpjjg = bglyssbpjjg;
    }

    public Double getPzysqtfwzmj() {
        return pzysqtfwzmj;
    }

    public void setPzysqtfwzmj(Double pzysqtfwzmj) {
        this.pzysqtfwzmj = pzysqtfwzmj;
    }

    public Double getQtfwsbpjjg() {
        return qtfwsbpjjg;
    }

    public void setQtfwsbpjjg(Double qtfwsbpjjg) {
        this.qtfwsbpjjg = qtfwsbpjjg;
    }

    public String getXkzh() {
        return xkzh;
    }

    public void setXkzh(String xkzh) {
        this.xkzh = xkzh;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getSfzx() {
        return sfzx;
    }

    public void setSfzx(String sfzx) {
        this.sfzx = sfzx;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getLx() {
        return lx;
    }

    public void setLx(String lx) {
        this.lx = lx;
    }

    public Date getYsyxqz() {
        return ysyxqz;
    }

    public void setYsyxqz(Date ysyxqz) {
        this.ysyxqz = ysyxqz;
    }

    public String getXsdl() {
        return xsdl;
    }

    public void setXsdl(String xsdl) {
        this.xsdl = xsdl;
    }

    public Date getKgrq() {
        return kgrq;
    }

    public void setKgrq(Date kgrq) {
        this.kgrq = kgrq;
    }

    public Date getJfrq() {
        return jfrq;
    }

    public void setJfrq(Date jfrq) {
        this.jfrq = jfrq;
    }

    public String getWqzxbz() {
        return wqzxbz;
    }

    public void setWqzxbz(String wqzxbz) {
        this.wqzxbz = wqzxbz;
    }

    public String getNqzxbz() {
        return nqzxbz;
    }

    public void setNqzxbz(String nqzxbz) {
        this.nqzxbz = nqzxbz;
    }

    public String getDpzxbz() {
        return dpzxbz;
    }

    public void setDpzxbz(String dpzxbz) {
        this.dpzxbz = dpzxbz;
    }

    public String getDmzxbz() {
        return dmzxbz;
    }

    public void setDmzxbz(String dmzxbz) {
        this.dmzxbz = dmzxbz;
    }

    public String getQtzxbz() {
        return qtzxbz;
    }

    public void setQtzxbz(String qtzxbz) {
        this.qtzxbz = qtzxbz;
    }

    public String getZkzyzh() {
        return zkzyzh;
    }

    public void setZkzyzh(String zkzyzh) {
        this.zkzyzh = zkzyzh;
    }

    public String getKhh() {
        return khh;
    }

    public void setKhh(String khh) {
        this.khh = khh;
    }

    public String getHm() {
        return hm;
    }

    public void setHm(String hm) {
        this.hm = hm;
    }

    public String getGtbw() {
        return gtbw;
    }

    public void setGtbw(String gtbw) {
        this.gtbw = gtbw;
    }

    public Double getGtmj() {
        return gtmj;
    }

    public void setGtmj(Double gtmj) {
        this.gtmj = gtmj;
    }

    public String getWyglgs() {
        return wyglgs;
    }

    public void setWyglgs(String wyglgs) {
        this.wyglgs = wyglgs;
    }

    public String getWyfwfxm() {
        return wyfwfxm;
    }

    public void setWyfwfxm(String wyfwfxm) {
        this.wyfwfxm = wyfwfxm;
    }

    public String getZzsfbz() {
        return zzsfbz;
    }

    public void setZzsfbz(String zzsfbz) {
        this.zzsfbz = zzsfbz;
    }

    public String getSysfbz() {
        return sysfbz;
    }

    public void setSysfbz(String sysfbz) {
        this.sysfbz = sysfbz;
    }

    public String getBgsfbz() {
        return bgsfbz;
    }

    public void setBgsfbz(String bgsfbz) {
        this.bgsfbz = bgsfbz;
    }

    public String getCksfbz() {
        return cksfbz;
    }

    public void setCksfbz(String cksfbz) {
        this.cksfbz = cksfbz;
    }

    public String getQtsfbz() {
        return qtsfbz;
    }

    public void setQtsfbz(String qtsfbz) {
        this.qtsfbz = qtsfbz;
    }

    public Integer getZts() {
        return zts;
    }

    public void setZts(Integer zts) {
        this.zts = zts;
    }

    public Double getZje() {
        return zje;
    }

    public void setZje(Double zje) {
        this.zje = zje;
    }

    public Double getBlfjzmj() {
        return blfjzmj;
    }

    public void setBlfjzmj(Double blfjzmj) {
        this.blfjzmj = blfjzmj;
    }

    public Integer getBlfzts() {
        return blfzts;
    }

    public void setBlfzts(Integer blfzts) {
        this.blfzts = blfzts;
    }

    public String getSyyfjzgm() {
        return syyfjzgm;
    }

    public void setSyyfjzgm(String syyfjzgm) {
        this.syyfjzgm = syyfjzgm;
    }

    public String getSyyfsgjd() {
        return syyfsgjd;
    }

    public void setSyyfsgjd(String syyfsgjd) {
        this.syyfsgjd = syyfsgjd;
    }

    public Double getSyyfwctze() {
        return syyfwctze;
    }

    public void setSyyfwctze(Double syyfwctze) {
        this.syyfwctze = syyfwctze;
    }

    public String getSyyfysjg() {
        return syyfysjg;
    }

    public void setSyyfysjg(String syyfysjg) {
        this.syyfysjg = syyfysjg;
    }

    public String getZzyfjzgm() {
        return zzyfjzgm;
    }

    public void setZzyfjzgm(String zzyfjzgm) {
        this.zzyfjzgm = zzyfjzgm;
    }

    public String getZzyfsgjd() {
        return zzyfsgjd;
    }

    public void setZzyfsgjd(String zzyfsgjd) {
        this.zzyfsgjd = zzyfsgjd;
    }

    public Double getZzyfwctze() {
        return zzyfwctze;
    }

    public void setZzyfwctze(Double zzyfwctze) {
        this.zzyfwctze = zzyfwctze;
    }

    public String getZzyfysjg() {
        return zzyfysjg;
    }

    public void setZzyfysjg(String zzyfysjg) {
        this.zzyfysjg = zzyfysjg;
    }

    public String getFzyfjzgm() {
        return fzyfjzgm;
    }

    public void setFzyfjzgm(String fzyfjzgm) {
        this.fzyfjzgm = fzyfjzgm;
    }

    public String getFzyfsgjd() {
        return fzyfsgjd;
    }

    public void setFzyfsgjd(String fzyfsgjd) {
        this.fzyfsgjd = fzyfsgjd;
    }

    public Double getFzyfwctze() {
        return fzyfwctze;
    }

    public void setFzyfwctze(Double fzyfwctze) {
        this.fzyfwctze = fzyfwctze;
    }

    public String getFzyfysjg() {
        return fzyfysjg;
    }

    public void setFzyfysjg(String fzyfysjg) {
        this.fzyfysjg = fzyfysjg;
    }

    public String getPjjg() {
        return pjjg;
    }

    public void setPjjg(String pjjg) {
        this.pjjg = pjjg;
    }

    public Date getKprq() {
        return kprq;
    }

    public void setKprq(Date kprq) {
        this.kprq = kprq;
    }

    public String getSfkp() {
        return sfkp;
    }

    public void setSfkp(String sfkp) {
        this.sfkp = sfkp;
    }

    public String getSfyxt() {
        return sfyxt;
    }

    public void setSfyxt(String sfyxt) {
        this.sfyxt = sfyxt;
    }
}
